@@ -17,7 +17,8 @@ sub next {
 
     my $row;
     if ($self->{sth}) {
-        $row = $self->{sth}->fetchrow_hashref('NAME_lc');
+        $row = $self->{sth}->fetchrow_hashref;
+        $self->{select_columns} ||= $self->{sth}->{$self->{teng}->{fields_case}};
         unless ( $row ) {
             $self->{sth}->finish;
             $self->{sth} = undef;
@@ -32,10 +33,12 @@ sub next {
     } else {
         return $self->{row_class}->new(
             {
-                sql        => $self->{sql},
-                row_data   => $row,
-                teng       => $self->{teng},
-                table_name => $self->{table_name},
+                sql            => $self->{sql},
+                row_data       => $row,
+                teng           => $self->{teng},
+                table          => $self->{table},
+                table_name     => $self->{table_name},
+                select_columns => $self->{select_columns},
             }
         );
     }
@@ -43,11 +46,32 @@ sub next {
 
 sub all {
     my $self = shift;
-    my @result;
-    while ( my $row = $self->next ) {
-        push @result, $row;
+
+    my $result = [];
+
+    if ($self->{sth}) {
+        $self->{select_columns} ||= $self->{sth}->{$self->{teng}->{fields_case}};
+        $result = $self->{sth}->fetchall_arrayref(+{});
+        $self->{sth}->finish;
+        $self->{sth} = undef;
+
+        if (!$self->{suppress_object_creation}) {
+            $result = [map {
+                $self->{row_class}->new(
+                    {
+                        sql            => $self->{sql},
+                        row_data       => $_,
+                        teng           => $self->{teng},
+                        table          => $self->{table},
+                        table_name     => $self->{table_name},
+                        select_columns => $self->{select_columns},
+                    }
+                )
+            } @$result];
+        }
     }
-    return wantarray ? @result : \@result;
+
+    return wantarray ? @$result : $result;
 }
 
 1;
@@ -88,9 +112,11 @@ Get next row data.
 
 Get all row data in array.
 
-=item $itr->suppress_object_creation($mode)
+=item $itr->suppress_object_creation($bool)
 
 Set row object creation mode.
 
+=back
+
 =cut
 
